import { Struct, type JsonValue } from '@bufbuild/protobuf';
import type { CallOptions } from '@connectrpc/connect';
import type { RobotClient } from '../../robot';
import type { Options } from '../../types';
import type { Motor } from './motor';
/**
 * A gRPC-web client for the Motor component.
 *
 * @group Clients
 */
export declare class MotorClient implements Motor {
    private client;
    readonly name: string;
    private readonly options;
    callOptions: CallOptions;
    constructor(client: RobotClient, name: string, options?: Options);
    setPower(power: number, extra?: {}, callOptions?: CallOptions): Promise<void>;
    goFor(rpm: number, revolutions: number, extra?: {}, callOptions?: CallOptions): Promise<void>;
    goTo(rpm: number, positionRevolutions: number, extra?: {}, callOptions?: CallOptions): Promise<void>;
    setRPM(rpm: number, extra?: {}, callOptions?: CallOptions): Promise<void>;
    resetZeroPosition(offset: number, extra?: {}, callOptions?: CallOptions): Promise<void>;
    stop(extra?: {}, callOptions?: CallOptions): Promise<void>;
    getProperties(extra?: {}, callOptions?: CallOptions): Promise<{
        positionReporting: boolean;
    }>;
    getPosition(extra?: {}, callOptions?: CallOptions): Promise<number>;
    isPowered(extra?: {}, callOptions?: CallOptions): Promise<readonly [boolean, number]>;
    isMoving(callOptions?: CallOptions): Promise<boolean>;
    doCommand(command: Struct, callOptions?: CallOptions): Promise<JsonValue>;
}
