import { Struct, type JsonValue } from '@bufbuild/protobuf';
import type { CallOptions } from '@connectrpc/connect';
import type { MimeType } from '../../main';
import type { RobotClient } from '../../robot';
import type { Options } from '../../types';
import type { CaptureAllOptions } from './types';
import type { Vision } from './vision';
/**
 * A gRPC-web client for a Vision service.
 *
 * @group Clients
 */
export declare class VisionClient implements Vision {
    private client;
    readonly name: string;
    private readonly options;
    callOptions: CallOptions;
    constructor(client: RobotClient, name: string, options?: Options);
    getDetectionsFromCamera(cameraName: string, extra?: {}, callOptions?: CallOptions): Promise<import("../../gen/service/vision/v1/vision_pb").Detection[]>;
    getDetections(image: Uint8Array, width: number, height: number, mimeType: MimeType, extra?: {}, callOptions?: CallOptions): Promise<import("../../gen/service/vision/v1/vision_pb").Detection[]>;
    getClassificationsFromCamera(cameraName: string, count: number, extra?: {}, callOptions?: CallOptions): Promise<import("../../gen/service/vision/v1/vision_pb").Classification[]>;
    getClassifications(image: Uint8Array, width: number, height: number, mimeType: MimeType, count: number, extra?: {}, callOptions?: CallOptions): Promise<import("../../gen/service/vision/v1/vision_pb").Classification[]>;
    getObjectPointClouds(cameraName: string, extra?: {}, callOptions?: CallOptions): Promise<import("../../gen/common/v1/common_pb").PointCloudObject[]>;
    getProperties(extra?: {}, callOptions?: CallOptions): Promise<{
        classificationsSupported: boolean;
        detectionsSupported: boolean;
        objectPointCloudsSupported: boolean;
    }>;
    captureAllFromCamera(cameraName: string, { returnImage, returnClassifications, returnDetections, returnObjectPointClouds, }: CaptureAllOptions, extra?: {}, callOptions?: CallOptions): Promise<{
        image: import("../../gen/component/camera/v1/camera_pb").Image | undefined;
        classifications: import("../../gen/service/vision/v1/vision_pb").Classification[];
        detections: import("../../gen/service/vision/v1/vision_pb").Detection[];
        objectPointClouds: import("../../gen/common/v1/common_pb").PointCloudObject[];
        extra: Struct | undefined;
    }>;
    doCommand(command: Struct, callOptions?: CallOptions): Promise<JsonValue>;
}
